#[repr(u8)]pub enum MultiStore {
Standard(StandardMultiStore),
}Variants
Standard(StandardMultiStore)
Implementations
Sourceimpl MultiStore
impl MultiStore
pub fn standard(config: MultiStoreConfig) -> Self
Sourceimpl MultiStore
impl MultiStore
pub fn testing_memory() -> Self
pub fn testing_memory_with_eventbus(event_bus: EventBus) -> Self
Sourcepub fn hot(&self) -> Option<&HotStorage>
pub fn hot(&self) -> Option<&HotStorage>
Get access to the hot storage tier.
Returns None if the hot tier is not configured.
Sourceimpl MultiStore
impl MultiStore
Sourcepub fn range(
&self,
range: EncodedKeyRange,
version: CommitVersion,
batch_size: usize,
) -> MultiVersionRangeIterator<'_>
pub fn range( &self, range: EncodedKeyRange, version: CommitVersion, batch_size: usize, ) -> MultiVersionRangeIterator<'_>
Create an iterator for forward range queries.
This properly handles high version density by scanning until batch_size unique logical keys are collected. The iterator yields individual entries and maintains cursor state internally.
Sourcepub fn range_rev(
&self,
range: EncodedKeyRange,
version: CommitVersion,
batch_size: usize,
) -> MultiVersionRangeIterator<'_>
pub fn range_rev( &self, range: EncodedKeyRange, version: CommitVersion, batch_size: usize, ) -> MultiVersionRangeIterator<'_>
Create an iterator for reverse range queries.
This properly handles high version density by scanning until batch_size unique logical keys are collected. The iterator yields individual entries in reverse key order and maintains cursor state internally.