pub struct StandardMultiStore(/* private fields */);Implementations
Sourceimpl StandardMultiStore
impl StandardMultiStore
Sourcepub fn range_next(
&self,
cursor: &mut MultiVersionRangeCursor,
range: EncodedKeyRange,
version: CommitVersion,
batch_size: u64,
) -> Result<MultiVersionBatch>
pub fn range_next( &self, cursor: &mut MultiVersionRangeCursor, range: EncodedKeyRange, version: CommitVersion, batch_size: u64, ) -> Result<MultiVersionBatch>
Fetch the next batch of entries, continuing from cursor position.
This properly handles high version density by scanning until batch_size
unique logical keys are collected OR all tiers are exhausted.
Sourcepub fn range(
&self,
range: EncodedKeyRange,
version: CommitVersion,
batch_size: usize,
) -> MultiVersionRangeIter ⓘ
pub fn range( &self, range: EncodedKeyRange, version: CommitVersion, batch_size: usize, ) -> MultiVersionRangeIter ⓘ
Create an iterator for forward range queries.
This properly handles high version density by scanning until batch_size unique logical keys are collected. The iterator yields individual entries and maintains cursor state internally.
Sourcepub fn range_rev(
&self,
range: EncodedKeyRange,
version: CommitVersion,
batch_size: usize,
) -> MultiVersionRangeRevIter ⓘ
pub fn range_rev( &self, range: EncodedKeyRange, version: CommitVersion, batch_size: usize, ) -> MultiVersionRangeRevIter ⓘ
Create an iterator for reverse range queries.
This properly handles high version density by scanning until batch_size unique logical keys are collected. The iterator yields individual entries in reverse key order and maintains cursor state internally.
Sourceimpl StandardMultiStore
impl StandardMultiStore
pub fn new(config: MultiStoreConfig) -> Result<Self>
Sourcepub fn hot(&self) -> Option<&HotStorage>
pub fn hot(&self) -> Option<&HotStorage>
Get access to the hot storage tier.
Returns None if the hot tier is not configured.
Sourceimpl StandardMultiStore
impl StandardMultiStore
pub fn testing_memory() -> Self
pub fn testing_memory_with_eventbus(event_bus: EventBus) -> Self