pub struct DropRequest {
pub table: EntryKind,
pub key: CowVec<u8>,
pub up_to_version: Option<CommitVersion>,
pub keep_last_versions: Option<usize>,
pub commit_version: CommitVersion,
pub pending_version: Option<CommitVersion>,
}Expand description
A request to drop old versions of a key.
Fields
table: EntryKindThe table containing the key.
key: CowVec<u8>The logical key (without version suffix).
up_to_version: Option<CommitVersion>Drop versions below this threshold (if Some).
keep_last_versions: Option<usize>Keep this many most recent versions (if Some).
commit_version: CommitVersionThe commit version that created this drop request.
pending_version: Option<CommitVersion>A version being written in the same batch (to avoid race).